@@ -18,16 +18,15 @@
 
 #include "bridge.h"
 #include "functions.h"
-#include "interface.h"
-#include "support.h"
+#include "solve.h" /* run_dd */
 #include "window_board.h" /* board b */
 
 #include "window_card.h" /* board b */
 
-static GtkWidget *window_card = 0;
-static HandDisplay *hand_display = 0;
+static GtkWidget *window_card = NULL;
+static HandDisplay *hand_display = NULL;
 static int seat_null = 0;
-seat new_card_seat = west;
+static seat new_card_seat = west;
 
 void
 card_window_update (seat *cards)
@@ -50,7 +49,7 @@ card_window_update (seat *cards)
 	hand_display_draw (GTK_WIDGET (hand_display));
 }
 
-void
+static void
 set_new_card_seat (seat s)
 {
 	new_card_seat = s;
@@ -156,8 +155,10 @@ window_card_set_style (int style)
 void
 window_card_init (int style)
 {
-	if (window_card)
+	if (window_card) {
+		gtk_widget_show (window_card);
 		return;
+	}
 
 	GtkWidget *w = hand_display_new (HAND_DISPLAY_MODE_HAND_X);
 	hand_display = HAND_DISPLAY (w);
@@ -170,8 +171,8 @@ window_card_init (int style)
 			"card-drag-drop", G_CALLBACK (window_card_drag_drop), &seat_null);
 	hand_display_set_drag (hand_display, 1);
 
-	window_card = create_window_card ();
-	GtkWidget *vbox = lookup_widget (window_card, "vbox2");
+	window_card = glade_xml_get_widget (win->xml, "window_card");
+	GtkWidget *vbox = glade_xml_get_widget (win->xml, "vbox2");
 	gtk_widget_show (w);
 	gtk_box_pack_start_defaults (GTK_BOX (vbox), w);
 	gtk_widget_show (window_card);
@@ -180,12 +181,85 @@ window_card_init (int style)
 	window_card_set_style (style);
 }
 
-void
-window_card_delete (void)
+gboolean
+on_window_card_delete_event            (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data)
 {
-	if (!window_card)
-		return;
-
-	gtk_widget_destroy (window_card);
-	window_card = 0;
+	printf ("delete... \n");
+	PROTECT_BEGIN_BOOL;
+	printf ("... delete\n");
+	GtkCheckMenuItem *menuitem = GTK_CHECK_MENU_ITEM (glade_xml_get_widget (win->xml, "cards1"));
+	gtk_check_menu_item_set_active (menuitem, FALSE);
+	gtk_widget_hide (window_card);
+	PROTECT_END;
+	return FALSE;
 }
+
+void
+on_cards1_activate                     (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+	PROTECT_BEGIN;
+	if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (menuitem))) {
+		window_card_init (win->hand_display_style);
+	} else
+		gtk_widget_hide (window_card);
+	PROTECT_END;
+}
+
+void
+on_radiotoolbutton_west_clicked        (GtkToolButton   *toolbutton,
+                                        gpointer         user_data)
+{
+	set_new_card_seat (west);
+}
+
+
+void
+on_radiotoolbutton_north_clicked       (GtkToolButton   *toolbutton,
+                                        gpointer         user_data)
+{
+	set_new_card_seat (north);
+}
+
+
+void
+on_radiotoolbutton_east_clicked        (GtkToolButton   *toolbutton,
+                                        gpointer         user_data)
+{
+	set_new_card_seat (east);
+}
+
+
+void
+on_radiotoolbutton_south_clicked       (GtkToolButton   *toolbutton,
+                                        gpointer         user_data)
+{
+	set_new_card_seat (south);
+}
+
+
+void
+on_toolbutton_card_wipe_clicked        (GtkToolButton   *toolbutton,
+                                        gpointer         user_data)
+{
+	board *b = CUR_BOARD;
+	board_clear(b);
+	card_window_update(b->dealt_cards);
+	show_board(b, REDRAW_HANDS | REDRAW_TRICKS | REDRAW_PAR);
+}
+
+
+void
+on_toolbutton_card_random_clicked      (GtkToolButton   *toolbutton,
+                                        gpointer         user_data)
+{
+	board *b = CUR_BOARD;
+	deal_random(b);
+	card_window_update(b->dealt_cards);
+	compute_dd_scores (b, run_dd);
+	show_board(b, REDRAW_HANDS | REDRAW_PAR);
+}
+
+
