@@ -17,8 +17,7 @@
 
 #include "bridge.h"
 #include "file.h"
-#include "interface.h"
-#include "support.h"
+#include "functions.h"
 #include "window_board.h"
 #include "window_card.h"
 
@@ -50,20 +49,65 @@ void line_entry_set_from_board(board *b)
 void window_line_entry_init(board *b)
 {
 	if (!window_line_entry) {
-		window_line_entry = create_window_line_entry ();
-		line_entry = GTK_ENTRY(lookup_widget(window_line_entry, "line_entry"));
+		window_line_entry = glade_xml_get_widget (win->xml, "window_line_entry");
+		line_entry = GTK_ENTRY(glade_xml_get_widget (win->xml, "line_entry"));
 		gtk_widget_show (window_line_entry);
 	}
 	if (b)
 		line_entry_set_from_board(b);
 }
 
-void window_line_entry_delete (board *b)
+static void
+window_line_entry_delete ()
 {
 	if (window_line_entry) {
-		gtk_widget_destroy (window_line_entry);
+		gtk_widget_hide (window_line_entry);
 		window_line_entry = NULL;
 		line_entry = NULL;
 	}
 }
 
+void
+on_deal_line_activate                  (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+	PROTECT_BEGIN;
+	if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (menuitem))) {
+		board *b = CUR_BOARD;
+		window_line_entry_init (b);
+	} else
+		window_line_entry_delete ();
+	PROTECT_END;
+}
+
+
+void
+on_line_entry_activate                 (GtkEntry        *entry,
+                                        gpointer         user_data)
+{
+	board *b = CUR_BOARD;
+	board_set_from_line_entry(b);
+}
+
+
+void
+on_line_entry_ok_clicked               (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	board *b = CUR_BOARD;
+	board_set_from_line_entry(b);
+}
+
+
+gboolean
+on_window_line_entry_delete_event      (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data)
+{
+	PROTECT_BEGIN_BOOL;
+	GtkWidget *menuitem = glade_xml_get_widget (win->xml, "deal_line");
+	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem), FALSE);
+	window_line_entry_delete ();
+	PROTECT_END;
+	return FALSE;
+}
