@@ -17,8 +17,7 @@
 
 #include "bridge.h"
 #include "functions.h"
-#include "interface.h"
-#include "support.h"
+#include "window_board.h"
 
 static GtkWidget *window_play = 0;
 static GtkTable *play_table;
@@ -53,13 +52,13 @@ void window_play_update (board *b)
 	}
 }
 
-void window_play_init (board *b)
+void window_play_init (window_board_t *win, board *b)
 {
 	if (window_play)
 		return;
 
-	window_play = create_window_play();
-	play_table = GTK_TABLE(lookup_widget(window_play, "play_table"));
+	window_play = glade_xml_get_widget (win->xml, "window_play");
+	play_table = GTK_TABLE(glade_xml_get_widget (win->xml, "play_table"));
 	assert (play_table);
 	int cr, cc;
 	char str[20];
@@ -89,6 +88,27 @@ window_play_delete (void)
 	if (!window_play)
 		return;
 
-	gtk_widget_destroy (window_play);
+	gtk_widget_hide (window_play);
 	window_play = 0;
 }
+
+gboolean
+on_window_play_delete_event            (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data)
+{
+	GtkCheckMenuItem *menuitem = GTK_CHECK_MENU_ITEM (glade_xml_get_widget (win->xml, "play1"));
+	gtk_check_menu_item_set_active (menuitem, FALSE);
+	window_play_delete ();
+	return FALSE;
+}
+
+void
+on_play1_activate                      (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+	if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (menuitem)))
+		window_play_init (win, CUR_BOARD);
+	else
+		window_play_delete ();
+}
